@@ -43,7 +43,7 @@ use overload
 
 use Math::Symbolic::ExportConstants qw/:all/;
 
-our $VERSION = '0.108';
+our $VERSION = '0.109';
 
 =head1 METHODS
 
@@ -112,6 +112,51 @@ sub set_value {
 
 
 
+=head2 Method signature
+
+signature() returns a tree's signature.
+
+In the context of Math::Symbolic, signatures are the list of variables
+any given tree depends on. That means the tree "v*t+x" depends on the
+variables v, t, and x. Thus, applying signature() on the tree that would
+be parsed from above example yields the sorted list ('t', 'v', 'x').
+
+Constants do not depend on any variables and therefore return the empty list.
+Obviously, operators' dependencies vary.
+
+Math::Symbolic::Variable objects, however, may have a slightly more
+involved signature. By convention, Math::Symbolic variables depend on
+themselves. That means their signature contains their own name. But they
+can also depend on various other variables because variables themselves
+can be viewed as placeholders for more compicated terms. For example
+in mechanics, the acceleration of a particle depends on its mass and
+the sum of all forces acting on it. So the variable 'acceleration' would
+have the signature ('acceleration', 'force1', 'force2',..., 'mass', 'time').
+
+=cut
+
+sub signature {
+	my $self = shift;
+	my $sig = $self->{signature} || [];
+	return sort @$sig;
+}
+
+
+
+=head2 Method set_signature
+
+set_signature expects any number of variable identifiers as arguments.
+It sets a variable's signature to this list of identifiers.
+
+=cut
+
+sub set_signature {
+	croak
+	"Cannot set signature of non-Variable Math::Symbolic tree element.";
+}
+
+
+
 =head2 Method simplify
 
 Minimum method for term simpilification just clones.
