@@ -55,7 +55,7 @@ use Math::Symbolic::Derivative qw//;
 
 use base 'Math::Symbolic::Base';
 
-our $VERSION = '0.108';
+our $VERSION = '0.109';
 
 =head1 CLASS DATA
 
@@ -739,6 +739,40 @@ sub set_value {
 
 
 
+=head2 Method signature
+
+signature() returns a tree's signature.
+
+In the context of Math::Symbolic, signatures are the list of variables
+any given tree depends on. That means the tree "v*t+x" depends on the
+variables v, t, and x. Thus, applying signature() on the tree that would
+be parsed from above example yields the sorted list ('t', 'v', 'x').
+
+Constants do not depend on any variables and therefore return the empty list.
+Obviously, operators' dependencies vary.
+
+Math::Symbolic::Variable objects, however, may have a slightly more
+involved signature. By convention, Math::Symbolic variables depend on
+themselves. That means their signature contains their own name. But they
+can also depend on various other variables because variables themselves
+can be viewed as placeholders for more compicated terms. For example
+in mechanics, the acceleration of a particle depends on its mass and
+the sum of all forces acting on it. So the variable 'acceleration' would
+have the signature ('acceleration', 'force1', 'force2',..., 'mass', 'time').
+
+=cut
+
+sub signature {
+	my $self = shift;
+	my %sig;
+	foreach my $o (@{$self->{operands}}) {
+		$sig{$_} = undef for $o->signature();
+	}
+	return sort keys %sig;
+}
+
+
+
 =head2 Method apply_derivatives
 
 If the operator is a derivative, this applies the derivative to its
